=======
Credits
=======

Development Lead
----------------

* Dirk Moors <dirkmoors@gmail.com>

Contributors
------------

* Jef Geskens <jef.geskens@gmail.com>
* Michael Pölzl <michael.poelzl@gmail.com>
